﻿--{{{ Libraries

local RL = AceLibrary("Roster-2.1")
local Aura = AceLibrary("SpecialEvents-Aura-2.0")
local L = AceLibrary("AceLocale-2.2"):new("GridStatusHots")

--}}}
--

local timer1 = { }
local timer2 = { }
local playerClass, englishClass = UnitClass("player");
local hotspell=nil
local hotspellduration=nil
local gsh_target=nil
local dbsettings=nil

GridStatusHots = GridStatus:NewModule("GridStatusHots")
GridStatusHots.menuName = "My HoT spell"
GridStatusHots.options = false

--{{{ Localization

L:RegisterTranslations("enUS", function()
	return {
		["Renew"] = true,
		["Rejuvenation"] = true,
		["Regrowth"] = true,
	}
end)

L:RegisterTranslations("deDE", function() 
	return {
		["Renew"] = "Erneuerung",
		["Rejuvenation"] = "Verj\195\188ngung",
		["Regrowth"] = "Nachwachsen",
	}
end)

L:RegisterTranslations("koKR", function() 
	return {
		["Renew"] = "소생",
		["Rejuvenation"] = "회복",
		["Regrowth"] = "재생",
	}
end)

L:RegisterTranslations("frFR", function() 
	return {
		["Renew"] = "R\195\169novation",
		["Rejuvenation"] = "R\195\169cup\195\169ration",
		["Regrowth"] = "R\195\169tablissement",
	}
end)

L:RegisterTranslations("zhCN", function() 
	return {
		["Renew"] = "\230\191\162\229\164\191",
		["Rejuvenation"] = "\229\155\158\230\152\165\230\156\175",
		["Regrowth"] = "\230\132\136\229\191\136",
	}
end)

--}}}

--{{{ AceDB defaults
--
GridStatusHots.defaultDB = {
	debug = false,
	alert_renew = {
		enable = true,
		priority = 99,
		range = false,
		color = { r = 0, g = 1, b = 0, a = 1 },
	},
	alert_rejuv = {
		enable = true,
		priority = 99,
		range = false,
		color = { r = 0, g = 0, b = 1, a = 1 },
	},
	alert_regrow = {
		enable = true,
		priority = 99,
		range = false,
		color = { r = 1, g = 1, b = 1, a = 1 },
	},
}

--}}}

function GridStatusHots:OnInitialize()
	self.super.OnInitialize(self)
	if englishClass == "PRIEST" then
		self:RegisterStatus("alert_renew", "Buff: My Renew", alert_renew, true)
	end
	if englishClass == "DRUID" then
		self:RegisterStatus("alert_rejuv", "Buff :My Rejuvenation", alert_rejuv, true)
		self:RegisterStatus("alert_regrow", "Buff: My Regrowth", alert_regrow, true)
	end
end

function GridStatusHots:OnEnable()
	self:RegisterEvent("UNIT_SPELLCAST_SENT")
	self:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED", "UpdateHots")
	self:RegisterEvent("SpecialEvents_UnitBuffLost", "StopSpell")
	self:RegisterEvent("UNIT_HEALTH", "UpdateAll")
	self:RegisterEvent("UNIT_MANA", "UpdateAll")
end

function GridStatusHots:Reset()
	self.super.Reset(self)
end

function GridStatusHots:UNIT_SPELLCAST_SENT(unit, spell, rank, target)
	
	if spell == L["Renew"] then
		gsh_target = target
		hotspell = L["Renew"]
		hotspellduration = 14.9
		cstatus = "alert_renew"
		dbsettings=self.db.profile.alert_renew
	elseif spell == L["Rejuvenation"] then
		gsh_target = target
		hotspell = L["Rejuvenation"]
		hotspellduration = 11.9
		cstatus = "alert_rejuv"
		dbsettings=self.db.profile.alert_rejuv
	elseif spell == L["Regrowth"] then
		gsh_target = target
		hotspell = L["Regrowth"]
		hotspellduration = 20.9
		cstatus = "alert_regrow"
		dbsettings=self.db.profile.alert_regrow
	else
		gsh_target = nil
	end
end

function GridStatusHots:UpdateHots(target)
	if gsh_target and hotspell == L["Regrowth"] then
	        timer2[gsh_target] = { GetTime(), hotspellduration, cstatus, hotspell, dbsettings  }    
	        GridStatusHots:UpdateAll()
	elseif gsh_target then
		timer1[gsh_target] = { GetTime(), hotspellduration, cstatus, hotspell, dbsettings  }
		GridStatusHots:UpdateAll()
	end
end

function GridStatusHots:StopSpell()

	GridStatusHots:UpdateAll()
	for u in RL:IterateRoster() do
		local name = UnitName(u.unitid)
		if timer1[name] and (GetTime()-timer1[name][1]) > 1 then
			if (GetTime()-timer1[name][1]) > timer1[name][2] or not (Aura:UnitHasBuff(u.unitid, timer1[name][4])) then
				self.core:SendStatusLost(name, timer1[name][3])
				timer1[name] = nil
			end
		end
		if timer2[name] and (GetTime()-timer2[name][1]) > 1 then
			if (GetTime()-timer2[name][1]) > timer2[name][2] or not (Aura:UnitHasBuff(u.unitid, timer2[name][4])) then
				self.core:SendStatusLost(name, timer2[name][3])
				timer2[name] = nil
			end
		end
	end
end

function GridStatusHots:UpdateAll()
	for u in RL:IterateRoster() do
		local name = UnitName(u.unitid)
		if timer1[name] then
			local settings = timer1[name][5]
			local text = timer1[name][2]-(GetTime()-timer1[name][1])
			self:Debug(text)
			self.core:SendStatusGained(name, timer1[name][3],
				settings.priority,
				(settings.range and 40),
				settings.color,
				tostring(text)
			)
		end
		if timer2[name] then
			local settings = timer2[name][5]
			local text = timer2[name][2]-(GetTime()-timer2[name][1])
			self:Debug(text)
			self.core:SendStatusGained(name, timer2[name][3],
				settings.priority,
				(settings.range and 40),
				settings.color,
				tostring(text)
			)
		end
	end
end		


